@@ -7,7 +7,9 @@
 #pragma once
 
 #include <QWidget>
-#include <akonadi/private/protocol_p.h>
+using namespace Qt::Literals::StringLiterals;
+
+#include <private/protocol_p.h>
 
 class QModelIndex;
 class NotificationModel;
